Clazz.declarePackage("J.g3d");
Clazz.declareInterface(J.g3d, "G3DRenderer");
;//5.0.1-v4 Fri Sep 06 21:51:44 CDT 2024
